@@ -60,6 +60,10 @@ impl Prime {
             prime: rng.gen_prime(num_bits),
         }
     }
+
+    pub fn num_bits(&self) -> usize {
+        self.prime.bits()
+    }
 }
 
 /// Type for serialization and sending over the network
