@@ -105,11 +105,12 @@ impl EncryptedDeck {
     pub fn shuffle_encrypt<Rng: CryptoRng + RngCore>(
         &self,
         rsa_parameter: &RsaParameter,
-        rng: &mut Rng,
+        shuffle_rng: &mut Rng,
     ) -> (EncryptedDeck, Rsa) {
-        let key = Rsa::gen_with_parameter(rsa_parameter.clone(), rng);
+        let os_rng = &mut rand::rngs::OsRng;
+        let key = Rsa::gen_with_parameter(rsa_parameter.clone(), os_rng);
         let mut deck = self.encrypt(&key);
-        deck.cards.shuffle(rng);
+        deck.cards.shuffle(shuffle_rng);
         (deck, key)
     }
 
@@ -149,15 +150,15 @@ impl EncryptedDeck {
 
     /// removes shuffling key from cards and encrypts each card with a unique random key
     /// returns the deck and all card specific keys
-    pub fn encrypt_card_specific<Rng: CryptoRng + RngCore>(
+    pub fn encrypt_card_specific(
         &self,
         shuffle_key: &Rsa,
-        rsa_parameter: &RsaParameter,
-        rng: &mut Rng,
+        rsa_parameter: &RsaParameter
     ) -> (EncryptedDeck, Vec<Rsa>) {
+        let os_rng = &mut rand::rngs::OsRng;
         let keys: Vec<Rsa> = (0..self.cards.len())
             .into_iter()
-            .map(|_| Rsa::gen_with_parameter(rsa_parameter.clone(), rng))
+            .map(|_| Rsa::gen_with_parameter(rsa_parameter.clone(), os_rng))
             .collect();
         let deck = self.card_specific(shuffle_key, &keys);
         (deck, keys)
@@ -275,7 +276,7 @@ mod test {
         assert!(deck.is_shuffle_encrypt_valid(&key, &encrypted_deck));
 
         let (phase_2, phase_2_keys) =
-            encrypted_deck.encrypt_card_specific(&key, &rsa_parameter, rng);
+            encrypted_deck.encrypt_card_specific(&key, &rsa_parameter);
         assert!(encrypted_deck.is_encrypt_card_specific_valid(&key, &phase_2, &phase_2_keys));
     }
 
@@ -290,7 +291,7 @@ mod test {
         assert!(deck.is_shuffle_encrypt_valid(&key, &encrypted_deck));
 
         let (phase_2, phase_2_keys) =
-            encrypted_deck.encrypt_card_specific(&key, &rsa_parameter, rng);
+            encrypted_deck.encrypt_card_specific(&key, &rsa_parameter);
         assert!(encrypted_deck.is_encrypt_card_specific_valid(&key, &phase_2, &phase_2_keys));
 
         let mut decrypted: Vec<u32> = phase_2_keys
@@ -322,14 +323,14 @@ mod test {
 
         // shuffle phase 2
         let (a_phase_2, a_phase_2_keys) =
-            b_phase_1.encrypt_card_specific(&a_shuffle_key, &rsa_parameter, rng);
+            b_phase_1.encrypt_card_specific(&a_shuffle_key, &rsa_parameter);
         assert!(b_phase_1.is_encrypt_card_specific_valid(
             &a_shuffle_key,
             &a_phase_2,
             &a_phase_2_keys
         ));
         let (b_phase_2, b_phase_2_keys) =
-            a_phase_2.encrypt_card_specific(&b_shuffle_key, &rsa_parameter, rng);
+            a_phase_2.encrypt_card_specific(&b_shuffle_key, &rsa_parameter);
         assert!(a_phase_2.is_encrypt_card_specific_valid(
             &b_shuffle_key,
             &b_phase_2,
